# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'othersigdlg.ui'
#
# Created: Mon Nov 26 19:44:53 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_othersigdlg(object):
    def setupUi(self, othersigdlg):
        othersigdlg.setObjectName(_fromUtf8("othersigdlg"))
        othersigdlg.resize(404, 413)
        self.groupBox = QtGui.QGroupBox(othersigdlg)
        self.groupBox.setGeometry(QtCore.QRect(40, 60, 201, 351))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.stopsig = QtGui.QRadioButton(self.groupBox)
        self.stopsig.setGeometry(QtCore.QRect(40, 40, 116, 22))
        self.stopsig.setObjectName(_fromUtf8("stopsig"))
        self.contsig = QtGui.QRadioButton(self.groupBox)
        self.contsig.setGeometry(QtCore.QRect(40, 70, 116, 22))
        self.contsig.setObjectName(_fromUtf8("contsig"))
        self.termsig = QtGui.QRadioButton(self.groupBox)
        self.termsig.setGeometry(QtCore.QRect(40, 100, 116, 22))
        self.termsig.setChecked(True)
        self.termsig.setObjectName(_fromUtf8("termsig"))
        self.killsig = QtGui.QRadioButton(self.groupBox)
        self.killsig.setGeometry(QtCore.QRect(40, 130, 116, 22))
        self.killsig.setChecked(False)
        self.killsig.setObjectName(_fromUtf8("killsig"))
        self.hupsig = QtGui.QRadioButton(self.groupBox)
        self.hupsig.setGeometry(QtCore.QRect(40, 160, 116, 22))
        self.hupsig.setChecked(False)
        self.hupsig.setObjectName(_fromUtf8("hupsig"))
        self.intsig = QtGui.QRadioButton(self.groupBox)
        self.intsig.setGeometry(QtCore.QRect(40, 190, 116, 22))
        self.intsig.setChecked(False)
        self.intsig.setObjectName(_fromUtf8("intsig"))
        self.quitsig = QtGui.QRadioButton(self.groupBox)
        self.quitsig.setGeometry(QtCore.QRect(40, 220, 116, 22))
        self.quitsig.setChecked(False)
        self.quitsig.setObjectName(_fromUtf8("quitsig"))
        self.alarmsig = QtGui.QRadioButton(self.groupBox)
        self.alarmsig.setGeometry(QtCore.QRect(40, 250, 116, 22))
        self.alarmsig.setChecked(False)
        self.alarmsig.setObjectName(_fromUtf8("alarmsig"))
        self.bussig = QtGui.QRadioButton(self.groupBox)
        self.bussig.setGeometry(QtCore.QRect(40, 280, 116, 22))
        self.bussig.setChecked(False)
        self.bussig.setObjectName(_fromUtf8("bussig"))
        self.segvsig = QtGui.QRadioButton(self.groupBox)
        self.segvsig.setGeometry(QtCore.QRect(40, 310, 141, 22))
        self.segvsig.setChecked(False)
        self.segvsig.setObjectName(_fromUtf8("segvsig"))
        self.buttonBox = QtGui.QDialogButtonBox(othersigdlg)
        self.buttonBox.setGeometry(QtCore.QRect(290, 60, 81, 81))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonBox.sizePolicy().hasHeightForWidth())
        self.buttonBox.setSizePolicy(sizePolicy)
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(othersigdlg)
        self.edjob.setGeometry(QtCore.QRect(90, 20, 221, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(othersigdlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 61, 17))
        self.label.setObjectName(_fromUtf8("label"))

        self.retranslateUi(othersigdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), othersigdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), othersigdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(othersigdlg)
        othersigdlg.setTabOrder(self.stopsig, self.contsig)
        othersigdlg.setTabOrder(self.contsig, self.termsig)
        othersigdlg.setTabOrder(self.termsig, self.killsig)
        othersigdlg.setTabOrder(self.killsig, self.hupsig)
        othersigdlg.setTabOrder(self.hupsig, self.intsig)
        othersigdlg.setTabOrder(self.intsig, self.quitsig)
        othersigdlg.setTabOrder(self.quitsig, self.alarmsig)
        othersigdlg.setTabOrder(self.alarmsig, self.bussig)
        othersigdlg.setTabOrder(self.bussig, self.segvsig)
        othersigdlg.setTabOrder(self.segvsig, self.buttonBox)

    def retranslateUi(self, othersigdlg):
        othersigdlg.setWindowTitle(QtGui.QApplication.translate("othersigdlg", "Select signal to kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("othersigdlg", "Signal to use", None, QtGui.QApplication.UnicodeUTF8))
        self.stopsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the stop signal", None, QtGui.QApplication.UnicodeUTF8))
        self.stopsig.setText(QtGui.QApplication.translate("othersigdlg", "Stop", None, QtGui.QApplication.UnicodeUTF8))
        self.contsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the continue signal", None, QtGui.QApplication.UnicodeUTF8))
        self.contsig.setText(QtGui.QApplication.translate("othersigdlg", "Continue", None, QtGui.QApplication.UnicodeUTF8))
        self.termsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the terminate signal", None, QtGui.QApplication.UnicodeUTF8))
        self.termsig.setText(QtGui.QApplication.translate("othersigdlg", "Terminate", None, QtGui.QApplication.UnicodeUTF8))
        self.killsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the kill signal", None, QtGui.QApplication.UnicodeUTF8))
        self.killsig.setText(QtGui.QApplication.translate("othersigdlg", "Kill", None, QtGui.QApplication.UnicodeUTF8))
        self.hupsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the hangup signal", None, QtGui.QApplication.UnicodeUTF8))
        self.hupsig.setText(QtGui.QApplication.translate("othersigdlg", "Hangup", None, QtGui.QApplication.UnicodeUTF8))
        self.intsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the interrupt signal", None, QtGui.QApplication.UnicodeUTF8))
        self.intsig.setText(QtGui.QApplication.translate("othersigdlg", "Interrupt", None, QtGui.QApplication.UnicodeUTF8))
        self.quitsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the quit signal", None, QtGui.QApplication.UnicodeUTF8))
        self.quitsig.setText(QtGui.QApplication.translate("othersigdlg", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.alarmsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the alarm signal", None, QtGui.QApplication.UnicodeUTF8))
        self.alarmsig.setText(QtGui.QApplication.translate("othersigdlg", "Alarm", None, QtGui.QApplication.UnicodeUTF8))
        self.bussig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the bus error signal", None, QtGui.QApplication.UnicodeUTF8))
        self.bussig.setText(QtGui.QApplication.translate("othersigdlg", "Bus", None, QtGui.QApplication.UnicodeUTF8))
        self.segvsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the segmentation error signal", None, QtGui.QApplication.UnicodeUTF8))
        self.segvsig.setText(QtGui.QApplication.translate("othersigdlg", "Segmentation", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("othersigdlg", "Kill job:", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jredirsdlg.ui'
#
# Created: Tue Nov 20 09:31:19 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jredirsdlg(object):
    def setupUi(self, jredirsdlg):
        jredirsdlg.setObjectName(_fromUtf8("jredirsdlg"))
        jredirsdlg.resize(644, 451)
        self.buttonBox = QtGui.QDialogButtonBox(jredirsdlg)
        self.buttonBox.setGeometry(QtCore.QRect(410, 400, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jredirsdlg)
        self.edjob.setGeometry(QtCore.QRect(120, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jredirsdlg)
        self.label.setGeometry(QtCore.QRect(20, 20, 91, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.redirlist = QtGui.QListWidget(jredirsdlg)
        self.redirlist.setGeometry(QtCore.QRect(20, 70, 591, 221))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setPointSize(10)
        self.redirlist.setFont(font)
        self.redirlist.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
        self.redirlist.setObjectName(_fromUtf8("redirlist"))
        self.newredir = QtGui.QPushButton(jredirsdlg)
        self.newredir.setGeometry(QtCore.QRect(20, 330, 98, 27))
        self.newredir.setObjectName(_fromUtf8("newredir"))
        self.delredir = QtGui.QPushButton(jredirsdlg)
        self.delredir.setGeometry(QtCore.QRect(510, 330, 98, 27))
        self.delredir.setObjectName(_fromUtf8("delredir"))

        self.retranslateUi(jredirsdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jredirsdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jredirsdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jredirsdlg)
        jredirsdlg.setTabOrder(self.redirlist, self.newredir)
        jredirsdlg.setTabOrder(self.newredir, self.delredir)
        jredirsdlg.setTabOrder(self.delredir, self.buttonBox)

    def retranslateUi(self, jredirsdlg):
        jredirsdlg.setWindowTitle(QtGui.QApplication.translate("jredirsdlg", "Job I/O Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jredirsdlg", "Redirs for job:", None, QtGui.QApplication.UnicodeUTF8))
        self.redirlist.setToolTip(QtGui.QApplication.translate("jredirsdlg", "These are the IO Redirections for the job.\n"
"\n"
"Drag and drop to re-order.\n"
"\n"
"Double-click to edit\n"
"\n"
"Click \"New\" to add a new redirections.\n"
"\n"
"Select an item and press \"Delete\" to delete an redirection.", None, QtGui.QApplication.UnicodeUTF8))
        self.newredir.setToolTip(QtGui.QApplication.translate("jredirsdlg", "Click this to add a new redirection", None, QtGui.QApplication.UnicodeUTF8))
        self.newredir.setText(QtGui.QApplication.translate("jredirsdlg", "New", None, QtGui.QApplication.UnicodeUTF8))
        self.delredir.setToolTip(QtGui.QApplication.translate("jredirsdlg", "Press this to delete the currently-selected redirection", None, QtGui.QApplication.UnicodeUTF8))
        self.delredir.setText(QtGui.QApplication.translate("jredirsdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'servlist.ui'
#
# Created: Fri Oct 26 13:10:09 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_serversdlg(object):
    def setupUi(self, serversdlg):
        serversdlg.setObjectName(_fromUtf8("serversdlg"))
        serversdlg.resize(832, 465)
        self.buttonBox = QtGui.QDialogButtonBox(serversdlg)
        self.buttonBox.setGeometry(QtCore.QRect(560, 400, 191, 41))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.Newserv = QtGui.QPushButton(serversdlg)
        self.Newserv.setGeometry(QtCore.QRect(20, 410, 93, 31))
        self.Newserv.setObjectName(_fromUtf8("Newserv"))
        self.Delserv = QtGui.QPushButton(serversdlg)
        self.Delserv.setGeometry(QtCore.QRect(140, 410, 93, 31))
        self.Delserv.setObjectName(_fromUtf8("Delserv"))
        self.label = QtGui.QLabel(serversdlg)
        self.label.setGeometry(QtCore.QRect(30, 60, 181, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.lahost = QtGui.QLineEdit(serversdlg)
        self.lahost.setGeometry(QtCore.QRect(210, 60, 271, 27))
        self.lahost.setObjectName(_fromUtf8("lahost"))
        self.servlist = QtGui.QTableWidget(serversdlg)
        self.servlist.setGeometry(QtCore.QRect(20, 110, 801, 231))
        self.servlist.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
        self.servlist.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.servlist.setShowGrid(False)
        self.servlist.setObjectName(_fromUtf8("servlist"))
        self.servlist.setColumnCount(7)
        self.servlist.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(3, item)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(4, item)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(5, item)
        item = QtGui.QTableWidgetItem()
        self.servlist.setHorizontalHeaderItem(6, item)
        self.servlist.verticalHeader().setVisible(False)
        self.dispUperms = QtGui.QPushButton(serversdlg)
        self.dispUperms.setGeometry(QtCore.QRect(540, 370, 211, 27))
        self.dispUperms.setObjectName(_fromUtf8("dispUperms"))
        self.label_2 = QtGui.QLabel(serversdlg)
        self.label_2.setGeometry(QtCore.QRect(30, 20, 141, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.wusername = QtGui.QLineEdit(serversdlg)
        self.wusername.setGeometry(QtCore.QRect(210, 10, 271, 27))
        self.wusername.setObjectName(_fromUtf8("wusername"))
        self.connectserv = QtGui.QPushButton(serversdlg)
        self.connectserv.setGeometry(QtCore.QRect(20, 370, 141, 27))
        self.connectserv.setObjectName(_fromUtf8("connectserv"))
        self.disconnserv = QtGui.QPushButton(serversdlg)
        self.disconnserv.setGeometry(QtCore.QRect(200, 370, 141, 27))
        self.disconnserv.setObjectName(_fromUtf8("disconnserv"))
        self.label_3 = QtGui.QLabel(serversdlg)
        self.label_3.setGeometry(QtCore.QRect(520, 60, 41, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.laport = QtGui.QComboBox(serversdlg)
        self.laport.setGeometry(QtCore.QRect(590, 60, 78, 27))
        self.laport.setEditable(True)
        self.laport.setObjectName(_fromUtf8("laport"))
        self.laport.addItem(_fromUtf8(""))
        self.laport.addItem(_fromUtf8(""))
        self.laport.addItem(_fromUtf8(""))
        self.laport.addItem(_fromUtf8(""))
        self.laport.addItem(_fromUtf8(""))
        self.laport.addItem(_fromUtf8(""))
        self.laport.addItem(_fromUtf8(""))
        self.getlafrom = QtGui.QPushButton(serversdlg)
        self.getlafrom.setGeometry(QtCore.QRect(390, 370, 98, 27))
        self.getlafrom.setObjectName(_fromUtf8("getlafrom"))
        self.setla = QtGui.QPushButton(serversdlg)
        self.setla.setGeometry(QtCore.QRect(710, 60, 61, 27))
        self.setla.setObjectName(_fromUtf8("setla"))

        self.retranslateUi(serversdlg)
        self.laport.setCurrentIndex(0)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), serversdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), serversdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(serversdlg)
        serversdlg.setTabOrder(self.wusername, self.lahost)
        serversdlg.setTabOrder(self.lahost, self.laport)
        serversdlg.setTabOrder(self.laport, self.setla)
        serversdlg.setTabOrder(self.setla, self.servlist)
        serversdlg.setTabOrder(self.servlist, self.connectserv)
        serversdlg.setTabOrder(self.connectserv, self.disconnserv)
        serversdlg.setTabOrder(self.disconnserv, self.Newserv)
        serversdlg.setTabOrder(self.Newserv, self.Delserv)
        serversdlg.setTabOrder(self.Delserv, self.getlafrom)
        serversdlg.setTabOrder(self.getlafrom, self.dispUperms)
        serversdlg.setTabOrder(self.dispUperms, self.buttonBox)

    def retranslateUi(self, serversdlg):
        serversdlg.setWindowTitle(QtGui.QApplication.translate("serversdlg", "Servers List", None, QtGui.QApplication.UnicodeUTF8))
        self.Newserv.setToolTip(QtGui.QApplication.translate("serversdlg", "Add a new server to the list", None, QtGui.QApplication.UnicodeUTF8))
        self.Newserv.setText(QtGui.QApplication.translate("serversdlg", "New", None, QtGui.QApplication.UnicodeUTF8))
        self.Delserv.setToolTip(QtGui.QApplication.translate("serversdlg", "Delete the currently-selected server", None, QtGui.QApplication.UnicodeUTF8))
        self.Delserv.setText(QtGui.QApplication.translate("serversdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("serversdlg", "Obtain local address from", None, QtGui.QApplication.UnicodeUTF8))
        self.lahost.setToolTip(QtGui.QApplication.translate("serversdlg", "<html><head/><body><p>Use this host to discover what &quot;my&quot; IP address is. This can be a web address or another machine in the same network. Make sure you get the port number right - it should be 80 for web hosts.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.servlist.setToolTip(QtGui.QApplication.translate("serversdlg", "List of servers we speak to - double-click to edit", None, QtGui.QApplication.UnicodeUTF8))
        self.servlist.setSortingEnabled(True)
        item = self.servlist.horizontalHeaderItem(0)
        item.setText(QtGui.QApplication.translate("serversdlg", "Server", None, QtGui.QApplication.UnicodeUTF8))
        item = self.servlist.horizontalHeaderItem(1)
        item.setText(QtGui.QApplication.translate("serversdlg", "Alias", None, QtGui.QApplication.UnicodeUTF8))
        item = self.servlist.horizontalHeaderItem(2)
        item.setText(QtGui.QApplication.translate("serversdlg", "IP", None, QtGui.QApplication.UnicodeUTF8))
        item = self.servlist.horizontalHeaderItem(3)
        item.setText(QtGui.QApplication.translate("serversdlg", "User", None, QtGui.QApplication.UnicodeUTF8))
        item = self.servlist.horizontalHeaderItem(4)
        item.setText(QtGui.QApplication.translate("serversdlg", "A/C", None, QtGui.QApplication.UnicodeUTF8))
        item = self.servlist.horizontalHeaderItem(5)
        item.setText(QtGui.QApplication.translate("serversdlg", "Conn", None, QtGui.QApplication.UnicodeUTF8))
        item = self.servlist.horizontalHeaderItem(6)
        item.setText(QtGui.QApplication.translate("serversdlg", "Sync", None, QtGui.QApplication.UnicodeUTF8))
        self.dispUperms.setToolTip(QtGui.QApplication.translate("serversdlg", "Display user permissions on server", None, QtGui.QApplication.UnicodeUTF8))
        self.dispUperms.setText(QtGui.QApplication.translate("serversdlg", "User Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("serversdlg", "Windows user name", None, QtGui.QApplication.UnicodeUTF8))
        self.wusername.setToolTip(QtGui.QApplication.translate("serversdlg", "This is the windows user name", None, QtGui.QApplication.UnicodeUTF8))
        self.connectserv.setToolTip(QtGui.QApplication.translate("serversdlg", "Click here to connect to server", None, QtGui.QApplication.UnicodeUTF8))
        self.connectserv.setText(QtGui.QApplication.translate("serversdlg", "Connect", None, QtGui.QApplication.UnicodeUTF8))
        self.disconnserv.setToolTip(QtGui.QApplication.translate("serversdlg", "Click here to disconnect from server", None, QtGui.QApplication.UnicodeUTF8))
        self.disconnserv.setText(QtGui.QApplication.translate("serversdlg", "Disconnect", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("serversdlg", "Port", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setToolTip(QtGui.QApplication.translate("serversdlg", "<html><head/><body><p>Specify the port number to use with the host given to get the local address. Use port 80 if it\'s a web server to get the HTTP port.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(0, QtGui.QApplication.translate("serversdlg", "80", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(1, QtGui.QApplication.translate("serversdlg", "22", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(2, QtGui.QApplication.translate("serversdlg", "23", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(3, QtGui.QApplication.translate("serversdlg", "25", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(4, QtGui.QApplication.translate("serversdlg", "515", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(5, QtGui.QApplication.translate("serversdlg", "2000", None, QtGui.QApplication.UnicodeUTF8))
        self.laport.setItemText(6, QtGui.QApplication.translate("serversdlg", "2200", None, QtGui.QApplication.UnicodeUTF8))
        self.getlafrom.setToolTip(QtGui.QApplication.translate("serversdlg", "<html><head/><body><p>Click to say that you want to get the local IP address from the selected server.</p><p>It will try some likely ports, starting with what you put in the port number at the top.</p><p><br/></p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.getlafrom.setText(QtGui.QApplication.translate("serversdlg", "LA from", None, QtGui.QApplication.UnicodeUTF8))
        self.setla.setToolTip(QtGui.QApplication.translate("serversdlg", "<html><head/><body><p>Press this to obtain local address from the host and port given and if OK do this each time.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.setla.setText(QtGui.QApplication.translate("serversdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'portdlg.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_portdlg(object):
    def setupUi(self, portdlg):
        portdlg.setObjectName(_fromUtf8("portdlg"))
        portdlg.resize(551, 370)
        self.buttonBox = QtGui.QDialogButtonBox(portdlg)
        self.buttonBox.setGeometry(QtCore.QRect(180, 320, 341, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(portdlg)
        self.label.setGeometry(QtCore.QRect(90, 20, 371, 18))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 127, 127))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Light, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 63, 63))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(170, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.BrightText, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 127, 127))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.AlternateBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ToolTipBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ToolTipText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 127, 127))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Light, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 63, 63))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(170, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.BrightText, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 127, 127))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.AlternateBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ToolTipBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ToolTipText, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 127, 127))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Light, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 63, 63))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(170, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.BrightText, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.AlternateBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ToolTipBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ToolTipText, brush)
        self.label.setPalette(palette)
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName(_fromUtf8("label"))
        self.layoutWidget = QtGui.QWidget(portdlg)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 50, 511, 251))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.gridLayout = QtGui.QGridLayout(self.layoutWidget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.setDefs = QtGui.QPushButton(self.layoutWidget)
        self.setDefs.setObjectName(_fromUtf8("setDefs"))
        self.gridLayout.addWidget(self.setDefs, 0, 0, 1, 1)
        self.label_2 = QtGui.QLabel(self.layoutWidget)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 0, 1, 1, 1)
        self.adjAllBy = QtGui.QSpinBox(self.layoutWidget)
        self.adjAllBy.setMinimum(1)
        self.adjAllBy.setMaximum(10000)
        self.adjAllBy.setSingleStep(10)
        self.adjAllBy.setProperty("value", 1000)
        self.adjAllBy.setObjectName(_fromUtf8("adjAllBy"))
        self.gridLayout.addWidget(self.adjAllBy, 0, 2, 1, 1)
        self.plus = QtGui.QPushButton(self.layoutWidget)
        self.plus.setObjectName(_fromUtf8("plus"))
        self.gridLayout.addWidget(self.plus, 0, 3, 1, 1)
        self.minus = QtGui.QPushButton(self.layoutWidget)
        self.minus.setObjectName(_fromUtf8("minus"))
        self.gridLayout.addWidget(self.minus, 0, 4, 1, 1)
        self.label_3 = QtGui.QLabel(self.layoutWidget)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.clientAccessPort = QtGui.QSpinBox(self.layoutWidget)
        self.clientAccessPort.setMinimum(1)
        self.clientAccessPort.setMaximum(65536)
        self.clientAccessPort.setProperty("value", 2250)
        self.clientAccessPort.setObjectName(_fromUtf8("clientAccessPort"))
        self.gridLayout.addWidget(self.clientAccessPort, 1, 1, 1, 1)
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 1, 2, 1, 2)
        self.label_4 = QtGui.QLabel(self.layoutWidget)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.gridLayout.addWidget(self.label_4, 2, 0, 1, 1)
        self.connectUDP = QtGui.QSpinBox(self.layoutWidget)
        self.connectUDP.setMinimum(1)
        self.connectUDP.setMaximum(65536)
        self.connectUDP.setProperty("value", 2050)
        self.connectUDP.setObjectName(_fromUtf8("connectUDP"))
        self.gridLayout.addWidget(self.connectUDP, 2, 1, 1, 1)
        self.label_5 = QtGui.QLabel(self.layoutWidget)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.gridLayout.addWidget(self.label_5, 2, 2, 1, 2)
        self.connectTCP = QtGui.QSpinBox(self.layoutWidget)
        self.connectTCP.setMinimum(1)
        self.connectTCP.setMaximum(65536)
        self.connectTCP.setProperty("value", 2050)
        self.connectTCP.setObjectName(_fromUtf8("connectTCP"))
        self.gridLayout.addWidget(self.connectTCP, 2, 4, 1, 1)
        self.label_6 = QtGui.QLabel(self.layoutWidget)
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.gridLayout.addWidget(self.label_6, 3, 0, 1, 1)
        self.viewTCP = QtGui.QSpinBox(self.layoutWidget)
        self.viewTCP.setMinimum(1)
        self.viewTCP.setMaximum(65536)
        self.viewTCP.setProperty("value", 2150)
        self.viewTCP.setObjectName(_fromUtf8("viewTCP"))
        self.gridLayout.addWidget(self.viewTCP, 3, 1, 1, 1)
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 3, 2, 1, 2)
        self.APITCP = QtGui.QSpinBox(self.layoutWidget)
        self.APITCP.setMinimum(1)
        self.APITCP.setMaximum(65536)
        self.APITCP.setProperty("value", 2260)
        self.APITCP.setObjectName(_fromUtf8("APITCP"))
        self.gridLayout.addWidget(self.APITCP, 4, 1, 1, 1)
        self.label_8 = QtGui.QLabel(self.layoutWidget)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.gridLayout.addWidget(self.label_8, 4, 2, 1, 2)
        self.APIUDP = QtGui.QSpinBox(self.layoutWidget)
        self.APIUDP.setMinimum(1)
        self.APIUDP.setMaximum(65536)
        self.APIUDP.setProperty("value", 2260)
        self.APIUDP.setObjectName(_fromUtf8("APIUDP"))
        self.gridLayout.addWidget(self.APIUDP, 4, 4, 1, 1)
        self.label_7 = QtGui.QLabel(self.layoutWidget)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.gridLayout.addWidget(self.label_7, 4, 0, 1, 1)
        self.label_3.setBuddy(self.clientAccessPort)
        self.label_4.setBuddy(self.connectUDP)
        self.label_5.setBuddy(self.connectTCP)
        self.label_6.setBuddy(self.viewTCP)
        self.label_8.setBuddy(self.APIUDP)
        self.label_7.setBuddy(self.APITCP)

        self.retranslateUi(portdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), portdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), portdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(portdlg)
        portdlg.setTabOrder(self.setDefs, self.adjAllBy)
        portdlg.setTabOrder(self.adjAllBy, self.plus)
        portdlg.setTabOrder(self.plus, self.minus)
        portdlg.setTabOrder(self.minus, self.clientAccessPort)
        portdlg.setTabOrder(self.clientAccessPort, self.connectUDP)
        portdlg.setTabOrder(self.connectUDP, self.connectTCP)
        portdlg.setTabOrder(self.connectTCP, self.viewTCP)
        portdlg.setTabOrder(self.viewTCP, self.APITCP)
        portdlg.setTabOrder(self.APITCP, self.APIUDP)
        portdlg.setTabOrder(self.APIUDP, self.buttonBox)

    def retranslateUi(self, portdlg):
        portdlg.setWindowTitle(QtGui.QApplication.translate("portdlg", "Set port numbers", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("portdlg", "Please be careful about setting these!!!", None, QtGui.QApplication.UnicodeUTF8))
        self.setDefs.setText(QtGui.QApplication.translate("portdlg", "Set defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("portdlg", "Adjust all by", None, QtGui.QApplication.UnicodeUTF8))
        self.plus.setText(QtGui.QApplication.translate("portdlg", "Plus", None, QtGui.QApplication.UnicodeUTF8))
        self.minus.setText(QtGui.QApplication.translate("portdlg", "Minus", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("portdlg", "&Client access", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("portdlg", "Connect - &probe", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("portdlg", "Connect (&TCP)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("portdlg", "Job &view (TCP)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("portdlg", "API (&UDP)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("portdlg", "&API (TCP)", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jargsdlg.ui'
#
# Created: Mon Nov 19 08:57:55 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jargsdlg(object):
    def setupUi(self, jargsdlg):
        jargsdlg.setObjectName(_fromUtf8("jargsdlg"))
        jargsdlg.resize(508, 414)
        self.buttonBox = QtGui.QDialogButtonBox(jargsdlg)
        self.buttonBox.setGeometry(QtCore.QRect(290, 370, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jargsdlg)
        self.edjob.setGeometry(QtCore.QRect(150, 30, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jargsdlg)
        self.label.setGeometry(QtCore.QRect(50, 30, 91, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.newarg = QtGui.QPushButton(jargsdlg)
        self.newarg.setGeometry(QtCore.QRect(50, 310, 98, 27))
        self.newarg.setObjectName(_fromUtf8("newarg"))
        self.delarg = QtGui.QPushButton(jargsdlg)
        self.delarg.setGeometry(QtCore.QRect(390, 310, 98, 27))
        self.delarg.setObjectName(_fromUtf8("delarg"))
        self.arglist = QtGui.QListWidget(jargsdlg)
        self.arglist.setGeometry(QtCore.QRect(50, 80, 441, 192))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setPointSize(10)
        self.arglist.setFont(font)
        self.arglist.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
        self.arglist.setObjectName(_fromUtf8("arglist"))

        self.retranslateUi(jargsdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jargsdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jargsdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jargsdlg)
        jargsdlg.setTabOrder(self.arglist, self.newarg)
        jargsdlg.setTabOrder(self.newarg, self.delarg)
        jargsdlg.setTabOrder(self.delarg, self.buttonBox)

    def retranslateUi(self, jargsdlg):
        jargsdlg.setWindowTitle(QtGui.QApplication.translate("jargsdlg", "Job Argument List", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jargsdlg", "Args for job:", None, QtGui.QApplication.UnicodeUTF8))
        self.newarg.setToolTip(QtGui.QApplication.translate("jargsdlg", "Click this to add a new argument", None, QtGui.QApplication.UnicodeUTF8))
        self.newarg.setText(QtGui.QApplication.translate("jargsdlg", "New", None, QtGui.QApplication.UnicodeUTF8))
        self.delarg.setToolTip(QtGui.QApplication.translate("jargsdlg", "Press this to delete the currently-selected argument", None, QtGui.QApplication.UnicodeUTF8))
        self.delarg.setText(QtGui.QApplication.translate("jargsdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.arglist.setToolTip(QtGui.QApplication.translate("jargsdlg", "These are the arguments for the job.\n"
"\n"
"Drag and drop to re-order.\n"
"\n"
"Double-click to edit\n"
"\n"
"Click \"New\" to add a new argument.\n"
"\n"
"Select an item and press \"Delete\" to delete an argument.", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jcondsdlg.ui'
#
# Created: Fri Nov 23 23:14:34 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jcondsdlg(object):
    def setupUi(self, jcondsdlg):
        jcondsdlg.setObjectName(_fromUtf8("jcondsdlg"))
        jcondsdlg.resize(852, 488)
        self.buttonBox = QtGui.QDialogButtonBox(jcondsdlg)
        self.buttonBox.setGeometry(QtCore.QRect(630, 440, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jcondsdlg)
        self.edjob.setGeometry(QtCore.QRect(170, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jcondsdlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(jcondsdlg)
        self.label_2.setGeometry(QtCore.QRect(60, 60, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(jcondsdlg)
        self.label_3.setGeometry(QtCore.QRect(160, 60, 41, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(jcondsdlg)
        self.label_4.setGeometry(QtCore.QRect(410, 60, 71, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(jcondsdlg)
        self.label_5.setGeometry(QtCore.QRect(640, 60, 66, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.widget = QtGui.QWidget(jcondsdlg)
        self.widget.setGeometry(QtCore.QRect(40, 90, 761, 336))
        self.widget.setObjectName(_fromUtf8("widget"))
        self.gridLayout = QtGui.QGridLayout(self.widget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.condvar0 = QtGui.QComboBox(self.widget)
        self.condvar0.setObjectName(_fromUtf8("condvar0"))
        self.condvar0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar0, 0, 0, 1, 1)
        self.condop0 = QtGui.QComboBox(self.widget)
        self.condop0.setObjectName(_fromUtf8("condop0"))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop0, 0, 1, 1, 1)
        self.condtext0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.condtext0.setFont(font)
        self.condtext0.setObjectName(_fromUtf8("condtext0"))
        self.gridLayout.addWidget(self.condtext0, 0, 2, 1, 1)
        self.textval0 = QtGui.QLineEdit(self.widget)
        self.textval0.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval0.setFont(font)
        self.textval0.setMaxLength(49)
        self.textval0.setObjectName(_fromUtf8("textval0"))
        self.gridLayout.addWidget(self.textval0, 0, 3, 1, 1)
        self.intval0 = QtGui.QSpinBox(self.widget)
        self.intval0.setMinimum(-1000000)
        self.intval0.setMaximum(1000000)
        self.intval0.setProperty("value", 0)
        self.intval0.setObjectName(_fromUtf8("intval0"))
        self.gridLayout.addWidget(self.intval0, 0, 4, 1, 1)
        self.cc0 = QtGui.QCheckBox(self.widget)
        self.cc0.setObjectName(_fromUtf8("cc0"))
        self.gridLayout.addWidget(self.cc0, 0, 5, 1, 1)
        self.condvar1 = QtGui.QComboBox(self.widget)
        self.condvar1.setObjectName(_fromUtf8("condvar1"))
        self.condvar1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar1, 1, 0, 1, 1)
        self.condop1 = QtGui.QComboBox(self.widget)
        self.condop1.setObjectName(_fromUtf8("condop1"))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop1, 1, 1, 1, 1)
        self.condtext1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.condtext1.setFont(font)
        self.condtext1.setObjectName(_fromUtf8("condtext1"))
        self.gridLayout.addWidget(self.condtext1, 1, 2, 1, 1)
        self.textval1 = QtGui.QLineEdit(self.widget)
        self.textval1.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval1.setFont(font)
        self.textval1.setMaxLength(49)
        self.textval1.setObjectName(_fromUtf8("textval1"))
        self.gridLayout.addWidget(self.textval1, 1, 3, 1, 1)
        self.intval1 = QtGui.QSpinBox(self.widget)
        self.intval1.setObjectName(_fromUtf8("intval1"))
        self.gridLayout.addWidget(self.intval1, 1, 4, 1, 1)
        self.cc1 = QtGui.QCheckBox(self.widget)
        self.cc1.setObjectName(_fromUtf8("cc1"))
        self.gridLayout.addWidget(self.cc1, 1, 5, 1, 1)
        self.condvar2 = QtGui.QComboBox(self.widget)
        self.condvar2.setObjectName(_fromUtf8("condvar2"))
        self.condvar2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar2, 2, 0, 1, 1)
        self.condop2 = QtGui.QComboBox(self.widget)
        self.condop2.setObjectName(_fromUtf8("condop2"))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop2, 2, 1, 1, 1)
        self.condtext2 = QtGui.QCheckBox(self.widget)
        self.condtext2.setObjectName(_fromUtf8("condtext2"))
        self.gridLayout.addWidget(self.condtext2, 2, 2, 1, 1)
        self.textval2 = QtGui.QLineEdit(self.widget)
        self.textval2.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval2.setFont(font)
        self.textval2.setMaxLength(49)
        self.textval2.setObjectName(_fromUtf8("textval2"))
        self.gridLayout.addWidget(self.textval2, 2, 3, 1, 1)
        self.intval2 = QtGui.QSpinBox(self.widget)
        self.intval2.setObjectName(_fromUtf8("intval2"))
        self.gridLayout.addWidget(self.intval2, 2, 4, 1, 1)
        self.cc2 = QtGui.QCheckBox(self.widget)
        self.cc2.setObjectName(_fromUtf8("cc2"))
        self.gridLayout.addWidget(self.cc2, 2, 5, 1, 1)
        self.condvar3 = QtGui.QComboBox(self.widget)
        self.condvar3.setObjectName(_fromUtf8("condvar3"))
        self.condvar3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar3, 3, 0, 1, 1)
        self.condop3 = QtGui.QComboBox(self.widget)
        self.condop3.setObjectName(_fromUtf8("condop3"))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop3, 3, 1, 1, 1)
        self.condtext3 = QtGui.QCheckBox(self.widget)
        self.condtext3.setObjectName(_fromUtf8("condtext3"))
        self.gridLayout.addWidget(self.condtext3, 3, 2, 1, 1)
        self.textval3 = QtGui.QLineEdit(self.widget)
        self.textval3.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval3.setFont(font)
        self.textval3.setMaxLength(49)
        self.textval3.setObjectName(_fromUtf8("textval3"))
        self.gridLayout.addWidget(self.textval3, 3, 3, 1, 1)
        self.intval3 = QtGui.QSpinBox(self.widget)
        self.intval3.setObjectName(_fromUtf8("intval3"))
        self.gridLayout.addWidget(self.intval3, 3, 4, 1, 1)
        self.cc3 = QtGui.QCheckBox(self.widget)
        self.cc3.setObjectName(_fromUtf8("cc3"))
        self.gridLayout.addWidget(self.cc3, 3, 5, 1, 1)
        self.condvar4 = QtGui.QComboBox(self.widget)
        self.condvar4.setObjectName(_fromUtf8("condvar4"))
        self.condvar4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar4, 4, 0, 1, 1)
        self.condop4 = QtGui.QComboBox(self.widget)
        self.condop4.setObjectName(_fromUtf8("condop4"))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop4, 4, 1, 1, 1)
        self.condtext4 = QtGui.QCheckBox(self.widget)
        self.condtext4.setObjectName(_fromUtf8("condtext4"))
        self.gridLayout.addWidget(self.condtext4, 4, 2, 1, 1)
        self.textval4 = QtGui.QLineEdit(self.widget)
        self.textval4.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval4.setFont(font)
        self.textval4.setMaxLength(49)
        self.textval4.setObjectName(_fromUtf8("textval4"))
        self.gridLayout.addWidget(self.textval4, 4, 3, 1, 1)
        self.intval4 = QtGui.QSpinBox(self.widget)
        self.intval4.setObjectName(_fromUtf8("intval4"))
        self.gridLayout.addWidget(self.intval4, 4, 4, 1, 1)
        self.cc4 = QtGui.QCheckBox(self.widget)
        self.cc4.setObjectName(_fromUtf8("cc4"))
        self.gridLayout.addWidget(self.cc4, 4, 5, 1, 1)
        self.condvar5 = QtGui.QComboBox(self.widget)
        self.condvar5.setObjectName(_fromUtf8("condvar5"))
        self.condvar5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar5, 5, 0, 1, 1)
        self.condop5 = QtGui.QComboBox(self.widget)
        self.condop5.setObjectName(_fromUtf8("condop5"))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop5, 5, 1, 1, 1)
        self.condtext5 = QtGui.QCheckBox(self.widget)
        self.condtext5.setObjectName(_fromUtf8("condtext5"))
        self.gridLayout.addWidget(self.condtext5, 5, 2, 1, 1)
        self.textval5 = QtGui.QLineEdit(self.widget)
        self.textval5.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval5.setFont(font)
        self.textval5.setMaxLength(49)
        self.textval5.setObjectName(_fromUtf8("textval5"))
        self.gridLayout.addWidget(self.textval5, 5, 3, 1, 1)
        self.intval5 = QtGui.QSpinBox(self.widget)
        self.intval5.setObjectName(_fromUtf8("intval5"))
        self.gridLayout.addWidget(self.intval5, 5, 4, 1, 1)
        self.cc5 = QtGui.QCheckBox(self.widget)
        self.cc5.setObjectName(_fromUtf8("cc5"))
        self.gridLayout.addWidget(self.cc5, 5, 5, 1, 1)
        self.condvar6 = QtGui.QComboBox(self.widget)
        self.condvar6.setObjectName(_fromUtf8("condvar6"))
        self.condvar6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar6, 6, 0, 1, 1)
        self.condop6 = QtGui.QComboBox(self.widget)
        self.condop6.setObjectName(_fromUtf8("condop6"))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop6, 6, 1, 1, 1)
        self.condtext6 = QtGui.QCheckBox(self.widget)
        self.condtext6.setObjectName(_fromUtf8("condtext6"))
        self.gridLayout.addWidget(self.condtext6, 6, 2, 1, 1)
        self.textval6 = QtGui.QLineEdit(self.widget)
        self.textval6.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval6.setFont(font)
        self.textval6.setMaxLength(49)
        self.textval6.setObjectName(_fromUtf8("textval6"))
        self.gridLayout.addWidget(self.textval6, 6, 3, 1, 1)
        self.intval6 = QtGui.QSpinBox(self.widget)
        self.intval6.setObjectName(_fromUtf8("intval6"))
        self.gridLayout.addWidget(self.intval6, 6, 4, 1, 1)
        self.cc6 = QtGui.QCheckBox(self.widget)
        self.cc6.setObjectName(_fromUtf8("cc6"))
        self.gridLayout.addWidget(self.cc6, 6, 5, 1, 1)
        self.condvar7 = QtGui.QComboBox(self.widget)
        self.condvar7.setObjectName(_fromUtf8("condvar7"))
        self.condvar7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar7, 7, 0, 1, 1)
        self.condop7 = QtGui.QComboBox(self.widget)
        self.condop7.setObjectName(_fromUtf8("condop7"))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop7, 7, 1, 1, 1)
        self.condtext7 = QtGui.QCheckBox(self.widget)
        self.condtext7.setObjectName(_fromUtf8("condtext7"))
        self.gridLayout.addWidget(self.condtext7, 7, 2, 1, 1)
        self.textval7 = QtGui.QLineEdit(self.widget)
        self.textval7.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval7.setFont(font)
        self.textval7.setMaxLength(49)
        self.textval7.setObjectName(_fromUtf8("textval7"))
        self.gridLayout.addWidget(self.textval7, 7, 3, 1, 1)
        self.intval7 = QtGui.QSpinBox(self.widget)
        self.intval7.setObjectName(_fromUtf8("intval7"))
        self.gridLayout.addWidget(self.intval7, 7, 4, 1, 1)
        self.cc7 = QtGui.QCheckBox(self.widget)
        self.cc7.setObjectName(_fromUtf8("cc7"))
        self.gridLayout.addWidget(self.cc7, 7, 5, 1, 1)
        self.condvar8 = QtGui.QComboBox(self.widget)
        self.condvar8.setObjectName(_fromUtf8("condvar8"))
        self.condvar8.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar8, 8, 0, 1, 1)
        self.condop8 = QtGui.QComboBox(self.widget)
        self.condop8.setObjectName(_fromUtf8("condop8"))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop8, 8, 1, 1, 1)
        self.condtext8 = QtGui.QCheckBox(self.widget)
        self.condtext8.setObjectName(_fromUtf8("condtext8"))
        self.gridLayout.addWidget(self.condtext8, 8, 2, 1, 1)
        self.textval8 = QtGui.QLineEdit(self.widget)
        self.textval8.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval8.setFont(font)
        self.textval8.setMaxLength(49)
        self.textval8.setObjectName(_fromUtf8("textval8"))
        self.gridLayout.addWidget(self.textval8, 8, 3, 1, 1)
        self.intval8 = QtGui.QSpinBox(self.widget)
        self.intval8.setObjectName(_fromUtf8("intval8"))
        self.gridLayout.addWidget(self.intval8, 8, 4, 1, 1)
        self.cc8 = QtGui.QCheckBox(self.widget)
        self.cc8.setObjectName(_fromUtf8("cc8"))
        self.gridLayout.addWidget(self.cc8, 8, 5, 1, 1)
        self.condvar9 = QtGui.QComboBox(self.widget)
        self.condvar9.setObjectName(_fromUtf8("condvar9"))
        self.condvar9.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar9, 9, 0, 1, 1)
        self.condop9 = QtGui.QComboBox(self.widget)
        self.condop9.setObjectName(_fromUtf8("condop9"))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop9, 9, 1, 1, 1)
        self.condtext9 = QtGui.QCheckBox(self.widget)
        self.condtext9.setObjectName(_fromUtf8("condtext9"))
        self.gridLayout.addWidget(self.condtext9, 9, 2, 1, 1)
        self.textval9 = QtGui.QLineEdit(self.widget)
        self.textval9.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval9.setFont(font)
        self.textval9.setMaxLength(49)
        self.textval9.setObjectName(_fromUtf8("textval9"))
        self.gridLayout.addWidget(self.textval9, 9, 3, 1, 1)
        self.intval9 = QtGui.QSpinBox(self.widget)
        self.intval9.setObjectName(_fromUtf8("intval9"))
        self.gridLayout.addWidget(self.intval9, 9, 4, 1, 1)
        self.cc9 = QtGui.QCheckBox(self.widget)
        self.cc9.setObjectName(_fromUtf8("cc9"))
        self.gridLayout.addWidget(self.cc9, 9, 5, 1, 1)

        self.retranslateUi(jcondsdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jcondsdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jcondsdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jcondsdlg)
        jcondsdlg.setTabOrder(self.condvar0, self.condop0)
        jcondsdlg.setTabOrder(self.condop0, self.condtext0)
        jcondsdlg.setTabOrder(self.condtext0, self.textval0)
        jcondsdlg.setTabOrder(self.textval0, self.intval0)
        jcondsdlg.setTabOrder(self.intval0, self.cc0)
        jcondsdlg.setTabOrder(self.cc0, self.condvar1)
        jcondsdlg.setTabOrder(self.condvar1, self.condop1)
        jcondsdlg.setTabOrder(self.condop1, self.condtext1)
        jcondsdlg.setTabOrder(self.condtext1, self.textval1)
        jcondsdlg.setTabOrder(self.textval1, self.intval1)
        jcondsdlg.setTabOrder(self.intval1, self.cc1)
        jcondsdlg.setTabOrder(self.cc1, self.condvar2)
        jcondsdlg.setTabOrder(self.condvar2, self.condop2)
        jcondsdlg.setTabOrder(self.condop2, self.condtext2)
        jcondsdlg.setTabOrder(self.condtext2, self.textval2)
        jcondsdlg.setTabOrder(self.textval2, self.intval2)
        jcondsdlg.setTabOrder(self.intval2, self.cc2)
        jcondsdlg.setTabOrder(self.cc2, self.condvar3)
        jcondsdlg.setTabOrder(self.condvar3, self.condop3)
        jcondsdlg.setTabOrder(self.condop3, self.condtext3)
        jcondsdlg.setTabOrder(self.condtext3, self.textval3)
        jcondsdlg.setTabOrder(self.textval3, self.intval3)
        jcondsdlg.setTabOrder(self.intval3, self.cc3)
        jcondsdlg.setTabOrder(self.cc3, self.condvar4)
        jcondsdlg.setTabOrder(self.condvar4, self.condop4)
        jcondsdlg.setTabOrder(self.condop4, self.condtext4)
        jcondsdlg.setTabOrder(self.condtext4, self.textval4)
        jcondsdlg.setTabOrder(self.textval4, self.intval4)
        jcondsdlg.setTabOrder(self.intval4, self.cc4)
        jcondsdlg.setTabOrder(self.cc4, self.condvar5)
        jcondsdlg.setTabOrder(self.condvar5, self.condop5)
        jcondsdlg.setTabOrder(self.condop5, self.condtext5)
        jcondsdlg.setTabOrder(self.condtext5, self.textval5)
        jcondsdlg.setTabOrder(self.textval5, self.intval5)
        jcondsdlg.setTabOrder(self.intval5, self.cc5)
        jcondsdlg.setTabOrder(self.cc5, self.condvar6)
        jcondsdlg.setTabOrder(self.condvar6, self.condop6)
        jcondsdlg.setTabOrder(self.condop6, self.condtext6)
        jcondsdlg.setTabOrder(self.condtext6, self.textval6)
        jcondsdlg.setTabOrder(self.textval6, self.intval6)
        jcondsdlg.setTabOrder(self.intval6, self.cc6)
        jcondsdlg.setTabOrder(self.cc6, self.condvar7)
        jcondsdlg.setTabOrder(self.condvar7, self.condop7)
        jcondsdlg.setTabOrder(self.condop7, self.condtext7)
        jcondsdlg.setTabOrder(self.condtext7, self.textval7)
        jcondsdlg.setTabOrder(self.textval7, self.intval7)
        jcondsdlg.setTabOrder(self.intval7, self.cc7)
        jcondsdlg.setTabOrder(self.cc7, self.condvar8)
        jcondsdlg.setTabOrder(self.condvar8, self.condop8)
        jcondsdlg.setTabOrder(self.condop8, self.condtext8)
        jcondsdlg.setTabOrder(self.condtext8, self.textval8)
        jcondsdlg.setTabOrder(self.textval8, self.intval8)
        jcondsdlg.setTabOrder(self.intval8, self.cc8)
        jcondsdlg.setTabOrder(self.cc8, self.condvar9)
        jcondsdlg.setTabOrder(self.condvar9, self.condop9)
        jcondsdlg.setTabOrder(self.condop9, self.condtext9)
        jcondsdlg.setTabOrder(self.condtext9, self.textval9)
        jcondsdlg.setTabOrder(self.textval9, self.intval9)
        jcondsdlg.setTabOrder(self.intval9, self.cc9)
        jcondsdlg.setTabOrder(self.cc9, self.buttonBox)

    def retranslateUi(self, jcondsdlg):
        jcondsdlg.setWindowTitle(QtGui.QApplication.translate("jcondsdlg", "Conditions for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jcondsdlg", "Conditions for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("jcondsdlg", "Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("jcondsdlg", "Op", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("jcondsdlg", "Text Value", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("jcondsdlg", "Int Val", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar0.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext0.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc0.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar1.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext1.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc1.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar2.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext2.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc2.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar3.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext3.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc3.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar4.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext4.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc4.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar5.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext5.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc5.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar6.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext6.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc6.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar7.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext7.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc7.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar8.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext8.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc8.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar9.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext9.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc9.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'assvardlg.ui'
#
# Created: Sun Nov 25 22:03:57 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_assvardlg(object):
    def setupUi(self, assvardlg):
        assvardlg.setObjectName(_fromUtf8("assvardlg"))
        assvardlg.resize(507, 234)
        self.buttonBox = QtGui.QDialogButtonBox(assvardlg)
        self.buttonBox.setGeometry(QtCore.QRect(300, 170, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(assvardlg)
        self.label.setGeometry(QtCore.QRect(10, 20, 101, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edvar = QtGui.QLabel(assvardlg)
        self.edvar.setGeometry(QtCore.QRect(110, 20, 301, 17))
        self.edvar.setText(_fromUtf8(""))
        self.edvar.setObjectName(_fromUtf8("edvar"))
        self.textval = QtGui.QLineEdit(assvardlg)
        self.textval.setEnabled(False)
        self.textval.setGeometry(QtCore.QRect(130, 110, 347, 28))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval.setFont(font)
        self.textval.setMaxLength(49)
        self.textval.setObjectName(_fromUtf8("textval"))
        self.label_3 = QtGui.QLabel(assvardlg)
        self.label_3.setGeometry(QtCore.QRect(30, 70, 51, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.istext = QtGui.QCheckBox(assvardlg)
        self.istext.setGeometry(QtCore.QRect(290, 70, 131, 22))
        self.istext.setObjectName(_fromUtf8("istext"))
        self.intval = QtGui.QSpinBox(assvardlg)
        self.intval.setGeometry(QtCore.QRect(130, 70, 101, 27))
        self.intval.setMinimum(-10000000)
        self.intval.setMaximum(10000000)
        self.intval.setObjectName(_fromUtf8("intval"))
        self.label_4 = QtGui.QLabel(assvardlg)
        self.label_4.setGeometry(QtCore.QRect(30, 120, 71, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))

        self.retranslateUi(assvardlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), assvardlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), assvardlg.reject)
        QtCore.QMetaObject.connectSlotsByName(assvardlg)
        assvardlg.setTabOrder(self.intval, self.istext)
        assvardlg.setTabOrder(self.istext, self.textval)
        assvardlg.setTabOrder(self.textval, self.buttonBox)

    def retranslateUi(self, assvardlg):
        assvardlg.setWindowTitle(QtGui.QApplication.translate("assvardlg", "Assign value to variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("assvardlg", "Assign var:", None, QtGui.QApplication.UnicodeUTF8))
        self.textval.setToolTip(QtGui.QApplication.translate("assvardlg", "Give the text value to be used if variable has to have this\n"
"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("assvardlg", "Value", None, QtGui.QApplication.UnicodeUTF8))
        self.istext.setToolTip(QtGui.QApplication.translate("assvardlg", "Indicates variable has text value", None, QtGui.QApplication.UnicodeUTF8))
        self.istext.setText(QtGui.QApplication.translate("assvardlg", "Has Text Value", None, QtGui.QApplication.UnicodeUTF8))
        self.intval.setToolTip(QtGui.QApplication.translate("assvardlg", "This is the value for the variable if an integer", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("assvardlg", "Text value", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'procpardlg.ui'
#
# Created: Wed Nov 14 21:42:49 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_procpardlg(object):
    def setupUi(self, procpardlg):
        procpardlg.setObjectName(_fromUtf8("procpardlg"))
        procpardlg.resize(624, 444)
        self.buttonBox = QtGui.QDialogButtonBox(procpardlg)
        self.buttonBox.setGeometry(QtCore.QRect(410, 390, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(procpardlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 81, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edjob = QtGui.QLabel(procpardlg)
        self.edjob.setGeometry(QtCore.QRect(130, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label_2 = QtGui.QLabel(procpardlg)
        self.label_2.setGeometry(QtCore.QRect(30, 50, 71, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.directory = QtGui.QLineEdit(procpardlg)
        self.directory.setGeometry(QtCore.QRect(130, 50, 461, 27))
        self.directory.setObjectName(_fromUtf8("directory"))
        self.groupBox = QtGui.QGroupBox(procpardlg)
        self.groupBox.setGeometry(QtCore.QRect(50, 100, 511, 131))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.um_ur = QtGui.QCheckBox(self.groupBox)
        self.um_ur.setGeometry(QtCore.QRect(20, 30, 97, 22))
        self.um_ur.setObjectName(_fromUtf8("um_ur"))
        self.um_uw = QtGui.QCheckBox(self.groupBox)
        self.um_uw.setGeometry(QtCore.QRect(20, 60, 97, 22))
        self.um_uw.setObjectName(_fromUtf8("um_uw"))
        self.um_ux = QtGui.QCheckBox(self.groupBox)
        self.um_ux.setGeometry(QtCore.QRect(20, 90, 121, 22))
        self.um_ux.setObjectName(_fromUtf8("um_ux"))
        self.um_gx = QtGui.QCheckBox(self.groupBox)
        self.um_gx.setGeometry(QtCore.QRect(160, 90, 131, 22))
        self.um_gx.setObjectName(_fromUtf8("um_gx"))
        self.um_gr = QtGui.QCheckBox(self.groupBox)
        self.um_gr.setGeometry(QtCore.QRect(160, 30, 111, 22))
        self.um_gr.setObjectName(_fromUtf8("um_gr"))
        self.um_gw = QtGui.QCheckBox(self.groupBox)
        self.um_gw.setGeometry(QtCore.QRect(160, 60, 121, 22))
        self.um_gw.setObjectName(_fromUtf8("um_gw"))
        self.um_ow = QtGui.QCheckBox(self.groupBox)
        self.um_ow.setGeometry(QtCore.QRect(340, 60, 121, 22))
        self.um_ow.setObjectName(_fromUtf8("um_ow"))
        self.um_or = QtGui.QCheckBox(self.groupBox)
        self.um_or.setGeometry(QtCore.QRect(340, 30, 111, 22))
        self.um_or.setObjectName(_fromUtf8("um_or"))
        self.um_ox = QtGui.QCheckBox(self.groupBox)
        self.um_ox.setGeometry(QtCore.QRect(340, 90, 131, 22))
        self.um_ox.setObjectName(_fromUtf8("um_ox"))
        self.label_3 = QtGui.QLabel(procpardlg)
        self.label_3.setGeometry(QtCore.QRect(40, 300, 101, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.norml = QtGui.QSpinBox(procpardlg)
        self.norml.setGeometry(QtCore.QRect(140, 290, 71, 27))
        self.norml.setMaximum(255)
        self.norml.setObjectName(_fromUtf8("norml"))
        self.label_4 = QtGui.QLabel(procpardlg)
        self.label_4.setGeometry(QtCore.QRect(220, 290, 21, 21))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.normu = QtGui.QSpinBox(procpardlg)
        self.normu.setGeometry(QtCore.QRect(250, 290, 71, 27))
        self.normu.setMaximum(255)
        self.normu.setObjectName(_fromUtf8("normu"))
        self.label_5 = QtGui.QLabel(procpardlg)
        self.label_5.setGeometry(QtCore.QRect(340, 290, 66, 21))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.errl = QtGui.QSpinBox(procpardlg)
        self.errl.setGeometry(QtCore.QRect(400, 290, 71, 27))
        self.errl.setMaximum(255)
        self.errl.setProperty("value", 1)
        self.errl.setObjectName(_fromUtf8("errl"))
        self.label_6 = QtGui.QLabel(procpardlg)
        self.label_6.setGeometry(QtCore.QRect(480, 290, 21, 21))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.erru = QtGui.QSpinBox(procpardlg)
        self.erru.setGeometry(QtCore.QRect(510, 290, 71, 27))
        self.erru.setMaximum(255)
        self.erru.setProperty("value", 255)
        self.erru.setObjectName(_fromUtf8("erru"))
        self.label_7 = QtGui.QLabel(procpardlg)
        self.label_7.setGeometry(QtCore.QRect(40, 240, 51, 17))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.ulimitv = QtGui.QSpinBox(procpardlg)
        self.ulimitv.setGeometry(QtCore.QRect(120, 230, 91, 27))
        self.ulimitv.setMaximum(1023)
        self.ulimitv.setObjectName(_fromUtf8("ulimitv"))
        self.ulimitmult = QtGui.QComboBox(procpardlg)
        self.ulimitmult.setGeometry(QtCore.QRect(250, 230, 81, 27))
        self.ulimitmult.setObjectName(_fromUtf8("ulimitmult"))
        self.ulimitmult.addItem(_fromUtf8(""))
        self.ulimitmult.addItem(_fromUtf8(""))
        self.ulimitmult.addItem(_fromUtf8(""))
        self.noadverr = QtGui.QCheckBox(procpardlg)
        self.noadverr.setGeometry(QtCore.QRect(50, 350, 181, 22))
        self.noadverr.setObjectName(_fromUtf8("noadverr"))
        self.exporttype = QtGui.QComboBox(procpardlg)
        self.exporttype.setGeometry(QtCore.QRect(270, 350, 151, 27))
        self.exporttype.setObjectName(_fromUtf8("exporttype"))
        self.exporttype.addItem(_fromUtf8(""))
        self.exporttype.addItem(_fromUtf8(""))
        self.exporttype.addItem(_fromUtf8(""))

        self.retranslateUi(procpardlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), procpardlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), procpardlg.reject)
        QtCore.QMetaObject.connectSlotsByName(procpardlg)
        procpardlg.setTabOrder(self.directory, self.um_ur)
        procpardlg.setTabOrder(self.um_ur, self.um_uw)
        procpardlg.setTabOrder(self.um_uw, self.um_ux)
        procpardlg.setTabOrder(self.um_ux, self.um_gr)
        procpardlg.setTabOrder(self.um_gr, self.um_gw)
        procpardlg.setTabOrder(self.um_gw, self.um_gx)
        procpardlg.setTabOrder(self.um_gx, self.um_or)
        procpardlg.setTabOrder(self.um_or, self.um_ow)
        procpardlg.setTabOrder(self.um_ow, self.um_ox)
        procpardlg.setTabOrder(self.um_ox, self.ulimitv)
        procpardlg.setTabOrder(self.ulimitv, self.ulimitmult)
        procpardlg.setTabOrder(self.ulimitmult, self.norml)
        procpardlg.setTabOrder(self.norml, self.normu)
        procpardlg.setTabOrder(self.normu, self.errl)
        procpardlg.setTabOrder(self.errl, self.erru)
        procpardlg.setTabOrder(self.erru, self.noadverr)
        procpardlg.setTabOrder(self.noadverr, self.exporttype)
        procpardlg.setTabOrder(self.exporttype, self.buttonBox)

    def retranslateUi(self, procpardlg):
        procpardlg.setWindowTitle(QtGui.QApplication.translate("procpardlg", "Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("procpardlg", "Editing job:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("procpardlg", "Directory:", None, QtGui.QApplication.UnicodeUTF8))
        self.directory.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the working directory for the job.\n"
"\n"
"Remember you can use ~user to give the user\'s home directory or $HOME\n"
"and so forth (but this will use the environment variables in the job).", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("procpardlg", "Umask - turn OFF", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ur.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off user read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ur.setText(QtGui.QApplication.translate("procpardlg", "User Read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_uw.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off user write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_uw.setText(QtGui.QApplication.translate("procpardlg", "User Write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ux.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off user execute/search", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ux.setText(QtGui.QApplication.translate("procpardlg", "User Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gx.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off group execute/search", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gx.setText(QtGui.QApplication.translate("procpardlg", "Group Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gr.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off group read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gr.setText(QtGui.QApplication.translate("procpardlg", "Group Read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gw.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off group write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gw.setText(QtGui.QApplication.translate("procpardlg", "Group Write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ow.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off others write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ow.setText(QtGui.QApplication.translate("procpardlg", "Others Write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_or.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off others read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_or.setText(QtGui.QApplication.translate("procpardlg", "Others Read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ox.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off others execute/search", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ox.setText(QtGui.QApplication.translate("procpardlg", "Others Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("procpardlg", "Exits - Normal", None, QtGui.QApplication.UnicodeUTF8))
        self.norml.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the lower bound of exit codes considered \"normal\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("procpardlg", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.normu.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the upper bound of exit codes considered \"normal\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("procpardlg", "Error", None, QtGui.QApplication.UnicodeUTF8))
        self.errl.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the lower bound of exit codes considered \"error\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("procpardlg", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.erru.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the upper bound of exit codes considered \"error\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("procpardlg", "Ulimit", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitv.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the value of the ulimit. Set 0 to indicate unlimited", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setToolTip(QtGui.QApplication.translate("procpardlg", "Give a multiplier here for the ulimit", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setItemText(0, QtGui.QApplication.translate("procpardlg", "Bytes", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setItemText(1, QtGui.QApplication.translate("procpardlg", "KB", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setItemText(2, QtGui.QApplication.translate("procpardlg", "MB", None, QtGui.QApplication.UnicodeUTF8))
        self.noadverr.setToolTip(QtGui.QApplication.translate("procpardlg", "Select this if time is not to be advanced on error", None, QtGui.QApplication.UnicodeUTF8))
        self.noadverr.setText(QtGui.QApplication.translate("procpardlg", "No advance on error", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setToolTip(QtGui.QApplication.translate("procpardlg", "Select export type\n"
"\n"
"Local means local only to current host\n"
"Exported means visible on other hosts, not executable\n"
"Remote runnable means it can run on other hosts.", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(0, QtGui.QApplication.translate("procpardlg", "Local only", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(1, QtGui.QApplication.translate("procpardlg", "Exported", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(2, QtGui.QApplication.translate("procpardlg", "Remote runnable", None, QtGui.QApplication.UnicodeUTF8))

